@@ -36,7 +36,7 @@ class BigMap
 public:
 	BigMap() : seq(0) {}
 
-	void map(int a, const string& b)
+	void assign(int a, const string& b)
 	{
 		tostring[a] = b;
 		toint[b] = a;
@@ -47,7 +47,7 @@ public:
 		std::map<string, int>::const_iterator i = toint.find(val);
 		if (i == toint.end())
 		{
-			map(seq, val);
+			assign(seq, val);
 			return seq++;
 		} else
 			return i->second;
